import { PlatformAccessory, CharacteristicValue, CharacteristicSetCallback, CharacteristicGetCallback } from 'homebridge';
import { SmartglassPlatform } from './platform';
/**
 * Platform Accessory
 * An instance of this class is created for each accessory your platform registers
 * Each accessory may expose multiple services of different service types.
 */
export declare class SmartglassAccessory {
    private readonly platform;
    private readonly accessory;
    private service;
    private speakerService;
    /**
     * These are just used to create a working example
     * You should implement your own code to track the state of your accessory
     */
    private exampleStates;
    private SGClient;
    private ApiClient;
    private deviceState;
    private inputSources;
    private appTitleCache;
    constructor(platform: SmartglassPlatform, accessory: PlatformAccessory);
    connectConsole(): void;
    getAppId(aum_id: string, title_id: string): number;
    getAppFromCache(title_id: string): any;
    getAppByTitleId(title_id: string): Promise<unknown>;
    /**
     * Handle "SET" requests from HomeKit
     * These are sent when the user changes the state of an accessory, for example, turning on a Light bulb.
     */
    setOn(value: CharacteristicValue, callback: CharacteristicSetCallback): void;
    /**
     * Handle the "GET" requests from HomeKit
     * These are sent when HomeKit wants to know the current state of the accessory, for example, checking if a Light bulb is on.
     *
     * GET requests should return as fast as possbile. A long delay here will result in
     * HomeKit being unresponsive and a bad user experience in general.
     *
     * If your device takes time to respond you should update the status of your device
     * asynchronously instead using the `updateCharacteristic` method instead.
  
     * @example
     * this.service.updateCharacteristic(this.platform.Characteristic.On, true)
     */
    getOn(callback: CharacteristicGetCallback): void;
    setRemoteKey(newValue: CharacteristicValue, callback: CharacteristicSetCallback): void;
    setVolume(value: CharacteristicValue, callback: CharacteristicSetCallback): void;
    setCurrentApplication(value: CharacteristicValue, callback: CharacteristicSetCallback): void;
    getCurrentApplication(callback: CharacteristicSetCallback): void;
    getModel(liveid: string): void;
}
//# sourceMappingURL=platformAccessory.d.ts.map